==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-74.js <==
dispMUA.arDispMUAAllocation["t"] =
{
  "toshiba network camera mailer" : [ "toshiba_network_camera2.png" ] ,
  "touchpoint campaign manager" : [ "touchpoint.png" ] ,
  "tva e-mail transfer client" : [ "tva.png" ] ,
  "the mailman replybot" : [ "mailman.png" , "http://www.list.org/" ] ,
  "tdc online webmail" : [ "tdc.png" ] ,
  "tcl email library" : [ "tcl.png" , "http://web.uvic.ca/~erempel/tcl/Email/Email.html" ] ,
  "tricorn autobahn" : [ "autobahn.png" ] ,
  "talisma netagent" : [ "talisma.png" ] ,
  "thingamajob.com" : [ "thingamajob_com.png" , "http://www.thingamajob.com/" ] ,
  "tsworks e-mail" : [ "tsworks.png" ] ,
  "testtrack smtp" : [ "testtrack.png" ] ,
  "tweakers.net" : [ "tweakers_net.png" , "http://www.tweakers.net/" ] ,
  "tutorials.de" : [ "tutorials_de.png" , "http://www.tutorials.de/" ] ,
  "thindata ems" : [ "thindata_ems.png" , "http://www.thindata.com/" ] ,
  "talisma mail" : [ "talisma.png" ] ,
  "tellmatic" : [ "tellmatic.png" ] ,
  "tapirmail" : [ "tapir_mail.png" ] ,
  "turukame" : [ "turukame.png" ] ,
  "turnpike" : [ "turnpike.png" ] ,
  "the bat!" : [ "the_bat.png" , "http://www.ritlabs.com/en/products/thebat/" ] ,
  "telebyte" : [ "telebyte.png" , "http://webmail.telebyte.nl/" ] ,
  "teamware" : [ "teamware.png" ] ,
  "t-online" : [ "t-online.png" , "http://www.t-online.de/" ] ,
  "tvnmail" : [ "tvnmail.png" ] ,
  "topdesk" : [ "topdesk.png" , "http://www.topdesk.com/" ] ,
  "tchibo" : [ "tchibo.png" , "http://www.tchibo.com/" ] ,
  "tal.de" : [ "tal_de.png" , "http://www.tal.de/" ] ,
  "typo3" : [ "typo3.png" ] ,
  "thoth" : [ "thoth.png" ] ,
  "telix" : [ "telix.png" ] ,
  "twig" : [ "twig.png" ] ,
  "trn " : [ "trn.png" ] ,
  "trac" : [ "trac.png" ] ,
  "tin/" : [ "tin.png" ] ,
  "toi" : [ "t-online.png" , "http://www.t-online.de/" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-74.js <==
dispMUA.arDispMUAAllocation["t"] =
{
  "toshiba network camera mailer" : [ "toshiba_network_camera2.png" ] ,
  "touchpoint campaign manager" : [ "touchpoint.png" ] ,
  "tva e-mail transfer client" : [ "tva.png" ] ,
  "the mailman replybot" : [ "mailman.png" , "http://www.list.org/" ] ,
  "tdc online webmail" : [ "tdc.png" ] ,
  "tcl email library" : [ "tcl.png" , "http://web.uvic.ca/~erempel/tcl/Email/Email.html" ] ,
  "tricorn autobahn" : [ "autobahn.png" ] ,
  "talisma netagent" : [ "talisma.png" ] ,
  "thingamajob.com" : [ "thingamajob_com.png" , "http://www.thingamajob.com/" ] ,
  "tsworks e-mail" : [ "tsworks.png" ] ,
  "testtrack smtp" : [ "testtrack.png" ] ,
  "tripolis mail" : [ "tripolis.png" , "http://www.tripolis.com/" ] ,
  "tweakers.net" : [ "tweakers_net.png" , "http://www.tweakers.net/" ] ,
  "tutorials.de" : [ "tutorials_de.png" , "http://www.tutorials.de/" ] ,
  "thindata ems" : [ "thindata_ems.png" , "http://www.thindata.com/" ] ,
  "talisma mail" : [ "talisma.png" ] ,
  "tmcnet.com" : [ "tmcnet_com.png" , "http://www.tmcnet.com/" ] ,
  "tellmatic" : [ "tellmatic.png" ] ,
  "tapirmail" : [ "tapir_mail.png" ] ,
  "turukame" : [ "turukame.png" ] ,
  "turnpike" : [ "turnpike.png" ] ,
  "the bat!" : [ "the_bat.png" , "http://www.ritlabs.com/en/products/thebat/" ] ,
  "telebyte" : [ "telebyte.png" , "http://webmail.telebyte.nl/" ] ,
  "teamware" : [ "teamware.png" ] ,
  "t-online" : [ "t-online.png" , "http://www.t-online.de/" ] ,
  "tvnmail" : [ "tvnmail.png" ] ,
  "topdesk" : [ "topdesk.png" , "http://www.topdesk.com/" ] ,
  "tchibo" : [ "tchibo.png" , "http://www.tchibo.com/" ] ,
  "tal.de" : [ "tal_de.png" , "http://www.tal.de/" ] ,
  "typo3" : [ "typo3.png" ] ,
  "thoth" : [ "thoth.png" ] ,
  "telix" : [ "telix.png" ] ,
  "twig" : [ "twig.png" ] ,
  "trn " : [ "trn.png" ] ,
  "trac" : [ "trac.png" ] ,
  "tin/" : [ "tin.png" ] ,
  "toi" : [ "t-online.png" , "http://www.t-online.de/" ] ,
}
